@@ -27,15 +27,20 @@ class DummyHttpClient:
     def post(self, url, json=None):
         self.last_post = (url, json)
         # Simulate different endpoints
-        if url == "confluence/create-groups":
+        if url in ("confluence/create-groups", "/confluence/create-groups"):
             return DummyResponse(200)
-        elif url == "confluence/create-l1-l2-objects":
+        elif url in ("confluence/create-l1-l2-objects", "/confluence/create-l1-l2-objects"):
             return DummyResponse(200)
-        elif url == "access/check":
-            # Return False for a specific l2_object_id to test negative case
-            if json and json.get("l2_object_id") == "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_19048045":
+        elif url in ("access/check", "/access/check"):
+            # Return False for a specific fgaObjectId to test negative case
+            if json and json.get("objectId") == "t417ce8a_Confluence_e4448be1-8022-43a2-b234-e467842aac60_19048045":
                 return DummyResponse(200, {"hasAccess": False})
             return DummyResponse(200, {"hasAccess": True})
+        elif url in ("auth/sync", "/auth/sync"):
+            return DummyResponse(200)
+        elif url in ("access/multi-check", "/access/multi-check"):
+            # This is handled in DummyHttpClientMulti
+            return DummyResponse(404)
         return DummyResponse(404)
 
 
@@ -53,7 +58,7 @@ def test_init_fga_success(monkeypatch):
     )
     sdk._IntelliOpsOpenFgaSDK__init_fga(model)
     # Should call both endpoints
-    assert sdk.http_client.last_post[0] == 'confluence/create-l1-l2-objects'
+    assert sdk.http_client.last_post[0].lstrip("/") == 'confluence/create-l1-l2-objects'
 
 
 def test_init_fga_http_error(monkeypatch):
@@ -99,7 +104,7 @@ def test_init_datasource_success():
     from intelliopsopenfgasdk_python.models import CreateDataSourceModel
     class DummyHttpClientDs(DummyHttpClient):
         def post(self, url, json=None):
-            assert url == "auth/sync"
+            assert url.lstrip("/") == "auth/sync"
             return DummyResponse(200)
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyHttpClientDs()
@@ -147,9 +152,10 @@ def test_initialize_calls_both(monkeypatch):
         refreshToken="refresh-token"
     )
     sdk.initialize(model)
-    assert "auth/sync" in sdk.http_client.calls
-    assert "confluence/create-groups" in sdk.http_client.calls
-    assert "confluence/create-l1-l2-objects" in sdk.http_client.calls
+    calls = [c.lstrip("/") for c in sdk.http_client.calls]
+    assert "auth/sync" in calls
+    assert "confluence/create-groups" in calls
+    assert "confluence/create-l1-l2-objects" in calls
 
 
 @pytest.mark.asyncio
@@ -157,7 +163,7 @@ def test_async_init_datasource_success():
     from intelliopsopenfgasdk_python.models import CreateDataSourceModel
     class DummyAsyncHttpClient(DummyHttpClient):
         async def async_post(self, url, json=None):
-            assert url == "auth/sync"
+            assert url.lstrip("/") == "auth/sync"
             return DummyResponse(200)
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyAsyncHttpClient()
@@ -221,7 +227,7 @@ def test_async_check_access_false():
 def test_check_multi_access():
     class DummyHttpClientMulti(DummyHttpClient):
         def post(self, url, json=None):
-            if url == "access/multi-check":
+            if url in ("access/multi-check", "/access/multi-check"):
                 return DummyResponse(200, {
                     "results": {
                         "results": [
@@ -254,7 +260,7 @@ def test_check_multi_access():
 def test_async_check_multi_access():
     class DummyAsyncHttpClientMulti(DummyHttpClient):
         async def async_post(self, url, json=None):
-            if url == "access/multi-check":
+            if url in ("access/multi-check", "/access/multi-check"):
                 return DummyResponse(200, {
                     "results": {
                         "results": [
@@ -264,7 +270,8 @@ def test_async_check_multi_access():
                         ]
                     }
                 })
-            return await super().post(url, json)
+            # Fallback for other endpoints
+            return DummyResponse(404)
     sdk = IntelliOpsOpenFgaSDK()
     sdk.http_client = DummyAsyncHttpClientMulti()
     model = CheckMultipleAccessModel(
